@@ -29,7 +29,7 @@ class Crawler:
         list_href = scraper.gethref()
         if list_href.count == 0 or not list_href: return None
         list_href.map(lambda x: x.url())
-        list_href.filter(self.visitedSites)
+        list_href.filter(self.visited)
         responses = self.fetcher.get_all_pages(list_href.contents)
         responses.removeErrors()
         return responses
