@@ -8,7 +8,7 @@ class href:
         self.subdomain = subdomain
     
     def url(self): 
-        url = self.subdomain + "." + self.origin + self.content
+        url = URL_PREFIX + self.subdomain + "." + self.origin + self.content
         try:
             scheme = self.content.split(":")[0]
             if scheme == "https": return self.content
